@@ -3,12 +3,14 @@
 {
     'name': 'Timesheet',
     'name_bg_BG': 'График',
+    'name_ca_ES': 'Fulls de treball',
     'name_de_DE': 'Zeiterfassung',
+    'name_es_AR': 'Partes de trabajo',
     'name_es_CO': 'Hoja de Asistencia',
     'name_es_ES': 'Partes de trabajo',
     'name_fr_FR': 'Feuille de présence',
     'name_nl_NL': 'Tijdregistratie',
-    'version': '2.2.2',
+    'version': '2.4.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -29,6 +31,15 @@ And with reports:
     - Часове за задача
     - Часове по служител за седмица
     - Часове по служител за месец
+''',
+    'description_ca_ES': '''Mòdul de fulls de treball amb:
+    - Feines o tasques
+    - Línies de fulls de treball
+
+I els informes:
+    - Hores per tasca
+    - Hores per empleat i setmana
+    - Hores per empleat i mes
 ''',
     'description_de_DE': '''Zeiterfassungsmodul mit:
     - Aufgaben
@@ -38,6 +49,15 @@ Zugehörige Berichte:
     - Stunden pro Aufgabe
     - Stunden pro Mitarbeiter pro Woche
     - Stunden pro Mitarbeiter pro Monat
+''',
+    'description_es_AR': '''Módulo de partes de trabajo con:
+    - Trabajo
+    - Línea de parte parte de trabajo
+
+Y con informes:
+    - Horas por trabajo
+    - Horas por empleado y semana
+    - Horas por empleado y mes
 ''',
     'description_es_CO': '''Módulo de Hoja de Asistencia con:
     - Trabajo
@@ -49,8 +69,8 @@ Y con reportes de:
     - Horas por empleado por mes
 ''',
     'description_es_ES': '''Módulo de partes de trabajo con:
-    - Trabajo
-    - Línea de parte parte de trabajo
+    - Trabajos o tareas
+    - Líneas de parte de trabajo
 
 Y con informes:
     - Horas por trabajo
@@ -89,7 +109,9 @@ Bijbehorende rapporten:
     'translation': [
         'locale/cs_CZ.po',
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
